# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.metatype_relationships_api import MetatypeRelationshipsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestMetatypeRelationshipsApi(unittest.TestCase):
    """MetatypeRelationshipsApi unit test stubs"""

    def setUp(self):
        self.api = MetatypeRelationshipsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_archive_metatype_relationship(self):
        """Test case for archive_metatype_relationship

        ArchiveMetatypeRelationship  # noqa: E501
        """
        pass

    def test_create_metatype_relationship(self):
        """Test case for create_metatype_relationship

        CreateMetatypeRelationship  # noqa: E501
        """
        pass

    def test_list_metatype_relationships(self):
        """Test case for list_metatype_relationships

        ListMetatypeRelationships  # noqa: E501
        """
        pass

    def test_retrieve_metatype_relationship(self):
        """Test case for retrieve_metatype_relationship

        RetrieveMetatypeRelationship  # noqa: E501
        """
        pass

    def test_update_metatype_relationship(self):
        """Test case for update_metatype_relationship

        UpdateMetatypeRelationship  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class FileModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'str',
        'id': 'str',
        'data_source_id': 'str',
        'created_at': 'str',
        'modified_at': 'str',
        'created_by': 'str',
        'modified_by': 'str',
        'reference': 'str',
        'status_message': 'str'
    }

    attribute_map = {
        'status': 'status',
        'id': 'id',
        'data_source_id': 'data_source_id',
        'created_at': 'created_at',
        'modified_at': 'modified_at',
        'created_by': 'created_by',
        'modified_by': 'modified_by',
        'reference': 'reference',
        'status_message': 'status_message'
    }

    def __init__(self, status=None, id=None, data_source_id=None, created_at=None, modified_at=None, created_by=None, modified_by=None, reference=None, status_message=None):  # noqa: E501
        """FileModel - a model defined in Swagger"""  # noqa: E501
        self._status = None
        self._id = None
        self._data_source_id = None
        self._created_at = None
        self._modified_at = None
        self._created_by = None
        self._modified_by = None
        self._reference = None
        self._status_message = None
        self.discriminator = None
        self.status = status
        self.id = id
        self.data_source_id = data_source_id
        self.created_at = created_at
        self.modified_at = modified_at
        self.created_by = created_by
        self.modified_by = modified_by
        self.reference = reference
        if status_message is not None:
            self.status_message = status_message

    @property
    def status(self):
        """Gets the status of this FileModel.  # noqa: E501


        :return: The status of this FileModel.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this FileModel.


        :param status: The status of this FileModel.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def id(self):
        """Gets the id of this FileModel.  # noqa: E501


        :return: The id of this FileModel.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this FileModel.


        :param id: The id of this FileModel.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def data_source_id(self):
        """Gets the data_source_id of this FileModel.  # noqa: E501


        :return: The data_source_id of this FileModel.  # noqa: E501
        :rtype: str
        """
        return self._data_source_id

    @data_source_id.setter
    def data_source_id(self, data_source_id):
        """Sets the data_source_id of this FileModel.


        :param data_source_id: The data_source_id of this FileModel.  # noqa: E501
        :type: str
        """
        if data_source_id is None:
            raise ValueError("Invalid value for `data_source_id`, must not be `None`")  # noqa: E501

        self._data_source_id = data_source_id

    @property
    def created_at(self):
        """Gets the created_at of this FileModel.  # noqa: E501


        :return: The created_at of this FileModel.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this FileModel.


        :param created_at: The created_at of this FileModel.  # noqa: E501
        :type: str
        """
        if created_at is None:
            raise ValueError("Invalid value for `created_at`, must not be `None`")  # noqa: E501

        self._created_at = created_at

    @property
    def modified_at(self):
        """Gets the modified_at of this FileModel.  # noqa: E501


        :return: The modified_at of this FileModel.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this FileModel.


        :param modified_at: The modified_at of this FileModel.  # noqa: E501
        :type: str
        """
        if modified_at is None:
            raise ValueError("Invalid value for `modified_at`, must not be `None`")  # noqa: E501

        self._modified_at = modified_at

    @property
    def created_by(self):
        """Gets the created_by of this FileModel.  # noqa: E501


        :return: The created_by of this FileModel.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this FileModel.


        :param created_by: The created_by of this FileModel.  # noqa: E501
        :type: str
        """
        if created_by is None:
            raise ValueError("Invalid value for `created_by`, must not be `None`")  # noqa: E501

        self._created_by = created_by

    @property
    def modified_by(self):
        """Gets the modified_by of this FileModel.  # noqa: E501


        :return: The modified_by of this FileModel.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this FileModel.


        :param modified_by: The modified_by of this FileModel.  # noqa: E501
        :type: str
        """
        if modified_by is None:
            raise ValueError("Invalid value for `modified_by`, must not be `None`")  # noqa: E501

        self._modified_by = modified_by

    @property
    def reference(self):
        """Gets the reference of this FileModel.  # noqa: E501


        :return: The reference of this FileModel.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this FileModel.


        :param reference: The reference of this FileModel.  # noqa: E501
        :type: str
        """
        if reference is None:
            raise ValueError("Invalid value for `reference`, must not be `None`")  # noqa: E501

        self._reference = reference

    @property
    def status_message(self):
        """Gets the status_message of this FileModel.  # noqa: E501


        :return: The status_message of this FileModel.  # noqa: E501
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """Sets the status_message of this FileModel.


        :param status_message: The status_message of this FileModel.  # noqa: E501
        :type: str
        """

        self._status_message = status_message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(FileModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CreateOrUpdateEdgesRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'container_id': 'str',
        'original_data_id': 'str',
        'data_source_id': 'str',
        'origin_node_id': 'str',
        'destination_node_id': 'str',
        'origin_node_original_id': 'str',
        'destination_node_original_id': 'str',
        'relationship_pair_id': 'str',
        'modified_at': 'str',
        'properties': 'object'
    }

    attribute_map = {
        'container_id': 'container_id',
        'original_data_id': 'original_data_id',
        'data_source_id': 'data_source_id',
        'origin_node_id': 'origin_node_id',
        'destination_node_id': 'destination_node_id',
        'origin_node_original_id': 'origin_node_original_id',
        'destination_node_original_id': 'destination_node_original_id',
        'relationship_pair_id': 'relationship_pair_id',
        'modified_at': 'modified_at',
        'properties': 'properties'
    }

    def __init__(self, container_id=None, original_data_id=None, data_source_id=None, origin_node_id=None, destination_node_id=None, origin_node_original_id=None, destination_node_original_id=None, relationship_pair_id=None, modified_at=None, properties=None):  # noqa: E501
        """CreateOrUpdateEdgesRequest - a model defined in Swagger"""  # noqa: E501
        self._container_id = None
        self._original_data_id = None
        self._data_source_id = None
        self._origin_node_id = None
        self._destination_node_id = None
        self._origin_node_original_id = None
        self._destination_node_original_id = None
        self._relationship_pair_id = None
        self._modified_at = None
        self._properties = None
        self.discriminator = None
        self.container_id = container_id
        self.original_data_id = original_data_id
        self.data_source_id = data_source_id
        self.origin_node_id = origin_node_id
        self.destination_node_id = destination_node_id
        self.origin_node_original_id = origin_node_original_id
        self.destination_node_original_id = destination_node_original_id
        self.relationship_pair_id = relationship_pair_id
        self.modified_at = modified_at
        self.properties = properties

    @property
    def container_id(self):
        """Gets the container_id of this CreateOrUpdateEdgesRequest.  # noqa: E501


        :return: The container_id of this CreateOrUpdateEdgesRequest.  # noqa: E501
        :rtype: str
        """
        return self._container_id

    @container_id.setter
    def container_id(self, container_id):
        """Sets the container_id of this CreateOrUpdateEdgesRequest.


        :param container_id: The container_id of this CreateOrUpdateEdgesRequest.  # noqa: E501
        :type: str
        """
        if container_id is None:
            raise ValueError("Invalid value for `container_id`, must not be `None`")  # noqa: E501

        self._container_id = container_id

    @property
    def original_data_id(self):
        """Gets the original_data_id of this CreateOrUpdateEdgesRequest.  # noqa: E501


        :return: The original_data_id of this CreateOrUpdateEdgesRequest.  # noqa: E501
        :rtype: str
        """
        return self._original_data_id

    @original_data_id.setter
    def original_data_id(self, original_data_id):
        """Sets the original_data_id of this CreateOrUpdateEdgesRequest.


        :param original_data_id: The original_data_id of this CreateOrUpdateEdgesRequest.  # noqa: E501
        :type: str
        """
        if original_data_id is None:
            raise ValueError("Invalid value for `original_data_id`, must not be `None`")  # noqa: E501

        self._original_data_id = original_data_id

    @property
    def data_source_id(self):
        """Gets the data_source_id of this CreateOrUpdateEdgesRequest.  # noqa: E501


        :return: The data_source_id of this CreateOrUpdateEdgesRequest.  # noqa: E501
        :rtype: str
        """
        return self._data_source_id

    @data_source_id.setter
    def data_source_id(self, data_source_id):
        """Sets the data_source_id of this CreateOrUpdateEdgesRequest.


        :param data_source_id: The data_source_id of this CreateOrUpdateEdgesRequest.  # noqa: E501
        :type: str
        """
        if data_source_id is None:
            raise ValueError("Invalid value for `data_source_id`, must not be `None`")  # noqa: E501

        self._data_source_id = data_source_id

    @property
    def origin_node_id(self):
        """Gets the origin_node_id of this CreateOrUpdateEdgesRequest.  # noqa: E501


        :return: The origin_node_id of this CreateOrUpdateEdgesRequest.  # noqa: E501
        :rtype: str
        """
        return self._origin_node_id

    @origin_node_id.setter
    def origin_node_id(self, origin_node_id):
        """Sets the origin_node_id of this CreateOrUpdateEdgesRequest.


        :param origin_node_id: The origin_node_id of this CreateOrUpdateEdgesRequest.  # noqa: E501
        :type: str
        """
        if origin_node_id is None:
            raise ValueError("Invalid value for `origin_node_id`, must not be `None`")  # noqa: E501

        self._origin_node_id = origin_node_id

    @property
    def destination_node_id(self):
        """Gets the destination_node_id of this CreateOrUpdateEdgesRequest.  # noqa: E501


        :return: The destination_node_id of this CreateOrUpdateEdgesRequest.  # noqa: E501
        :rtype: str
        """
        return self._destination_node_id

    @destination_node_id.setter
    def destination_node_id(self, destination_node_id):
        """Sets the destination_node_id of this CreateOrUpdateEdgesRequest.


        :param destination_node_id: The destination_node_id of this CreateOrUpdateEdgesRequest.  # noqa: E501
        :type: str
        """
        if destination_node_id is None:
            raise ValueError("Invalid value for `destination_node_id`, must not be `None`")  # noqa: E501

        self._destination_node_id = destination_node_id

    @property
    def origin_node_original_id(self):
        """Gets the origin_node_original_id of this CreateOrUpdateEdgesRequest.  # noqa: E501


        :return: The origin_node_original_id of this CreateOrUpdateEdgesRequest.  # noqa: E501
        :rtype: str
        """
        return self._origin_node_original_id

    @origin_node_original_id.setter
    def origin_node_original_id(self, origin_node_original_id):
        """Sets the origin_node_original_id of this CreateOrUpdateEdgesRequest.


        :param origin_node_original_id: The origin_node_original_id of this CreateOrUpdateEdgesRequest.  # noqa: E501
        :type: str
        """
        if origin_node_original_id is None:
            raise ValueError("Invalid value for `origin_node_original_id`, must not be `None`")  # noqa: E501

        self._origin_node_original_id = origin_node_original_id

    @property
    def destination_node_original_id(self):
        """Gets the destination_node_original_id of this CreateOrUpdateEdgesRequest.  # noqa: E501


        :return: The destination_node_original_id of this CreateOrUpdateEdgesRequest.  # noqa: E501
        :rtype: str
        """
        return self._destination_node_original_id

    @destination_node_original_id.setter
    def destination_node_original_id(self, destination_node_original_id):
        """Sets the destination_node_original_id of this CreateOrUpdateEdgesRequest.


        :param destination_node_original_id: The destination_node_original_id of this CreateOrUpdateEdgesRequest.  # noqa: E501
        :type: str
        """
        if destination_node_original_id is None:
            raise ValueError("Invalid value for `destination_node_original_id`, must not be `None`")  # noqa: E501

        self._destination_node_original_id = destination_node_original_id

    @property
    def relationship_pair_id(self):
        """Gets the relationship_pair_id of this CreateOrUpdateEdgesRequest.  # noqa: E501


        :return: The relationship_pair_id of this CreateOrUpdateEdgesRequest.  # noqa: E501
        :rtype: str
        """
        return self._relationship_pair_id

    @relationship_pair_id.setter
    def relationship_pair_id(self, relationship_pair_id):
        """Sets the relationship_pair_id of this CreateOrUpdateEdgesRequest.


        :param relationship_pair_id: The relationship_pair_id of this CreateOrUpdateEdgesRequest.  # noqa: E501
        :type: str
        """
        if relationship_pair_id is None:
            raise ValueError("Invalid value for `relationship_pair_id`, must not be `None`")  # noqa: E501

        self._relationship_pair_id = relationship_pair_id

    @property
    def modified_at(self):
        """Gets the modified_at of this CreateOrUpdateEdgesRequest.  # noqa: E501


        :return: The modified_at of this CreateOrUpdateEdgesRequest.  # noqa: E501
        :rtype: str
        """
        return self._modified_at

    @modified_at.setter
    def modified_at(self, modified_at):
        """Sets the modified_at of this CreateOrUpdateEdgesRequest.


        :param modified_at: The modified_at of this CreateOrUpdateEdgesRequest.  # noqa: E501
        :type: str
        """
        if modified_at is None:
            raise ValueError("Invalid value for `modified_at`, must not be `None`")  # noqa: E501

        self._modified_at = modified_at

    @property
    def properties(self):
        """Gets the properties of this CreateOrUpdateEdgesRequest.  # noqa: E501


        :return: The properties of this CreateOrUpdateEdgesRequest.  # noqa: E501
        :rtype: object
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this CreateOrUpdateEdgesRequest.


        :param properties: The properties of this CreateOrUpdateEdgesRequest.  # noqa: E501
        :type: object
        """
        if properties is None:
            raise ValueError("Invalid value for `properties`, must not be `None`")  # noqa: E501

        self._properties = properties

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateOrUpdateEdgesRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateOrUpdateEdgesRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import deep_lynx
from deep_lynx.api.tasks_api import TasksApi  # noqa: E501
from deep_lynx.rest import ApiException


class TestTasksApi(unittest.TestCase):
    """TasksApi unit test stubs"""

    def setUp(self):
        self.api = TasksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_containers_container_id_task(self):
        """Test case for get_containers_container_id_task

        List Tasks  # noqa: E501
        """
        pass

    def test_get_containers_container_id_task_task_id(self):
        """Test case for get_containers_container_id_task_task_id

        Get Task  # noqa: E501
        """
        pass

    def test_post_containers_container_id_task(self):
        """Test case for post_containers_container_id_task

        Create Task  # noqa: E501
        """
        pass

    def test_put_containers_container_id_task_task_id(self):
        """Test case for put_containers_container_id_task_task_id

        Update Task  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ExporterConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'kind': 'str',
        'key': 'str',
        'path': 'str',
        'port': 'str',
        'user': 'str',
        'endpoint': 'str',
        'graphson_v1': 'bool',
        'traversal_source': 'str',
        'writes_per_second': 'float'
    }

    attribute_map = {
        'kind': 'kind',
        'key': 'key',
        'path': 'path',
        'port': 'port',
        'user': 'user',
        'endpoint': 'endpoint',
        'graphson_v1': 'graphson_v1',
        'traversal_source': 'traversal_source',
        'writes_per_second': 'writes_per_second'
    }

    def __init__(self, kind=None, key=None, path=None, port=None, user=None, endpoint=None, graphson_v1=None, traversal_source=None, writes_per_second=None):  # noqa: E501
        """ExporterConfig - a model defined in Swagger"""  # noqa: E501
        self._kind = None
        self._key = None
        self._path = None
        self._port = None
        self._user = None
        self._endpoint = None
        self._graphson_v1 = None
        self._traversal_source = None
        self._writes_per_second = None
        self.discriminator = None
        self.kind = kind
        self.key = key
        self.path = path
        self.port = port
        self.user = user
        self.endpoint = endpoint
        self.graphson_v1 = graphson_v1
        self.traversal_source = traversal_source
        self.writes_per_second = writes_per_second

    @property
    def kind(self):
        """Gets the kind of this ExporterConfig.  # noqa: E501


        :return: The kind of this ExporterConfig.  # noqa: E501
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """Sets the kind of this ExporterConfig.


        :param kind: The kind of this ExporterConfig.  # noqa: E501
        :type: str
        """
        if kind is None:
            raise ValueError("Invalid value for `kind`, must not be `None`")  # noqa: E501

        self._kind = kind

    @property
    def key(self):
        """Gets the key of this ExporterConfig.  # noqa: E501


        :return: The key of this ExporterConfig.  # noqa: E501
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """Sets the key of this ExporterConfig.


        :param key: The key of this ExporterConfig.  # noqa: E501
        :type: str
        """
        if key is None:
            raise ValueError("Invalid value for `key`, must not be `None`")  # noqa: E501

        self._key = key

    @property
    def path(self):
        """Gets the path of this ExporterConfig.  # noqa: E501


        :return: The path of this ExporterConfig.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this ExporterConfig.


        :param path: The path of this ExporterConfig.  # noqa: E501
        :type: str
        """
        if path is None:
            raise ValueError("Invalid value for `path`, must not be `None`")  # noqa: E501

        self._path = path

    @property
    def port(self):
        """Gets the port of this ExporterConfig.  # noqa: E501


        :return: The port of this ExporterConfig.  # noqa: E501
        :rtype: str
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this ExporterConfig.


        :param port: The port of this ExporterConfig.  # noqa: E501
        :type: str
        """
        if port is None:
            raise ValueError("Invalid value for `port`, must not be `None`")  # noqa: E501

        self._port = port

    @property
    def user(self):
        """Gets the user of this ExporterConfig.  # noqa: E501


        :return: The user of this ExporterConfig.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this ExporterConfig.


        :param user: The user of this ExporterConfig.  # noqa: E501
        :type: str
        """
        if user is None:
            raise ValueError("Invalid value for `user`, must not be `None`")  # noqa: E501

        self._user = user

    @property
    def endpoint(self):
        """Gets the endpoint of this ExporterConfig.  # noqa: E501


        :return: The endpoint of this ExporterConfig.  # noqa: E501
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """Sets the endpoint of this ExporterConfig.


        :param endpoint: The endpoint of this ExporterConfig.  # noqa: E501
        :type: str
        """
        if endpoint is None:
            raise ValueError("Invalid value for `endpoint`, must not be `None`")  # noqa: E501

        self._endpoint = endpoint

    @property
    def graphson_v1(self):
        """Gets the graphson_v1 of this ExporterConfig.  # noqa: E501


        :return: The graphson_v1 of this ExporterConfig.  # noqa: E501
        :rtype: bool
        """
        return self._graphson_v1

    @graphson_v1.setter
    def graphson_v1(self, graphson_v1):
        """Sets the graphson_v1 of this ExporterConfig.


        :param graphson_v1: The graphson_v1 of this ExporterConfig.  # noqa: E501
        :type: bool
        """
        if graphson_v1 is None:
            raise ValueError("Invalid value for `graphson_v1`, must not be `None`")  # noqa: E501

        self._graphson_v1 = graphson_v1

    @property
    def traversal_source(self):
        """Gets the traversal_source of this ExporterConfig.  # noqa: E501


        :return: The traversal_source of this ExporterConfig.  # noqa: E501
        :rtype: str
        """
        return self._traversal_source

    @traversal_source.setter
    def traversal_source(self, traversal_source):
        """Sets the traversal_source of this ExporterConfig.


        :param traversal_source: The traversal_source of this ExporterConfig.  # noqa: E501
        :type: str
        """
        if traversal_source is None:
            raise ValueError("Invalid value for `traversal_source`, must not be `None`")  # noqa: E501

        self._traversal_source = traversal_source

    @property
    def writes_per_second(self):
        """Gets the writes_per_second of this ExporterConfig.  # noqa: E501


        :return: The writes_per_second of this ExporterConfig.  # noqa: E501
        :rtype: float
        """
        return self._writes_per_second

    @writes_per_second.setter
    def writes_per_second(self, writes_per_second):
        """Sets the writes_per_second of this ExporterConfig.


        :param writes_per_second: The writes_per_second of this ExporterConfig.  # noqa: E501
        :type: float
        """
        if writes_per_second is None:
            raise ValueError("Invalid value for `writes_per_second`, must not be `None`")  # noqa: E501

        self._writes_per_second = writes_per_second

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ExporterConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ExporterConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from deep_lynx.api_client import ApiClient


class GraphApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive_edge(self, container_id, edge_id, **kwargs):  # noqa: E501
        """Archive Edge  # noqa: E501

        Archives an edge  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.archive_edge(container_id, edge_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str edge_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.archive_edge_with_http_info(container_id, edge_id, **kwargs)  # noqa: E501
        else:
            (data) = self.archive_edge_with_http_info(container_id, edge_id, **kwargs)  # noqa: E501
            return data

    def archive_edge_with_http_info(self, container_id, edge_id, **kwargs):  # noqa: E501
        """Archive Edge  # noqa: E501

        Archives an edge  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.archive_edge_with_http_info(container_id, edge_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str edge_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'edge_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method archive_edge" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `archive_edge`")  # noqa: E501
        # verify the required parameter 'edge_id' is set
        if ('edge_id' not in params or
                params['edge_id'] is None):
            raise ValueError("Missing the required parameter `edge_id` when calling `archive_edge`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'edge_id' in params:
            path_params['edge_id'] = params['edge_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/graphs/edges/{edge_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def archive_node(self, container_id, node_id, **kwargs):  # noqa: E501
        """Archive Node  # noqa: E501

        Archives a node  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.archive_node(container_id, node_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str node_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.archive_node_with_http_info(container_id, node_id, **kwargs)  # noqa: E501
        else:
            (data) = self.archive_node_with_http_info(container_id, node_id, **kwargs)  # noqa: E501
            return data

    def archive_node_with_http_info(self, container_id, node_id, **kwargs):  # noqa: E501
        """Archive Node  # noqa: E501

        Archives a node  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.archive_node_with_http_info(container_id, node_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str node_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'node_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method archive_node" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `archive_node`")  # noqa: E501
        # verify the required parameter 'node_id' is set
        if ('node_id' not in params or
                params['node_id'] is None):
            raise ValueError("Missing the required parameter `node_id` when calling `archive_node`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'node_id' in params:
            path_params['node_id'] = params['node_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/graphs/nodes/{node_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def attach_edge_file(self, container_id, file_id, edge_id, **kwargs):  # noqa: E501
        """Attach Edge File  # noqa: E501

        Attach a file to an edge.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.attach_edge_file(container_id, file_id, edge_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str file_id: (required)
        :param str edge_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.attach_edge_file_with_http_info(container_id, file_id, edge_id, **kwargs)  # noqa: E501
        else:
            (data) = self.attach_edge_file_with_http_info(container_id, file_id, edge_id, **kwargs)  # noqa: E501
            return data

    def attach_edge_file_with_http_info(self, container_id, file_id, edge_id, **kwargs):  # noqa: E501
        """Attach Edge File  # noqa: E501

        Attach a file to an edge.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.attach_edge_file_with_http_info(container_id, file_id, edge_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str file_id: (required)
        :param str edge_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'file_id', 'edge_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method attach_edge_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `attach_edge_file`")  # noqa: E501
        # verify the required parameter 'file_id' is set
        if ('file_id' not in params or
                params['file_id'] is None):
            raise ValueError("Missing the required parameter `file_id` when calling `attach_edge_file`")  # noqa: E501
        # verify the required parameter 'edge_id' is set
        if ('edge_id' not in params or
                params['edge_id'] is None):
            raise ValueError("Missing the required parameter `edge_id` when calling `attach_edge_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'file_id' in params:
            path_params['file_id'] = params['file_id']  # noqa: E501
        if 'edge_id' in params:
            path_params['edge_id'] = params['edge_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/graphs/edges/{edge_id}/files/{file_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def attach_node_file(self, container_id, node_id, file_id, **kwargs):  # noqa: E501
        """Attach Node File  # noqa: E501

        Attach a file to a node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.attach_node_file(container_id, node_id, file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str node_id: (required)
        :param str file_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.attach_node_file_with_http_info(container_id, node_id, file_id, **kwargs)  # noqa: E501
        else:
            (data) = self.attach_node_file_with_http_info(container_id, node_id, file_id, **kwargs)  # noqa: E501
            return data

    def attach_node_file_with_http_info(self, container_id, node_id, file_id, **kwargs):  # noqa: E501
        """Attach Node File  # noqa: E501

        Attach a file to a node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.attach_node_file_with_http_info(container_id, node_id, file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str node_id: (required)
        :param str file_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'node_id', 'file_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method attach_node_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `attach_node_file`")  # noqa: E501
        # verify the required parameter 'node_id' is set
        if ('node_id' not in params or
                params['node_id'] is None):
            raise ValueError("Missing the required parameter `node_id` when calling `attach_node_file`")  # noqa: E501
        # verify the required parameter 'file_id' is set
        if ('file_id' not in params or
                params['file_id'] is None):
            raise ValueError("Missing the required parameter `file_id` when calling `attach_node_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'node_id' in params:
            path_params['node_id'] = params['node_id']  # noqa: E501
        if 'file_id' in params:
            path_params['file_id'] = params['file_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/graphs/nodes/{node_id}/files/{file_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_or_update_edges(self, container_id, **kwargs):  # noqa: E501
        """Create or Update Edges  # noqa: E501

        This endpoint will either create new edges or update edges if a `modified_at` property with a valid DateTime is passed.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_or_update_edges(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param CreateOrUpdateEdgesRequest body:
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_or_update_edges_with_http_info(container_id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_or_update_edges_with_http_info(container_id, **kwargs)  # noqa: E501
            return data

    def create_or_update_edges_with_http_info(self, container_id, **kwargs):  # noqa: E501
        """Create or Update Edges  # noqa: E501

        This endpoint will either create new edges or update edges if a `modified_at` property with a valid DateTime is passed.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_or_update_edges_with_http_info(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param CreateOrUpdateEdgesRequest body:
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_or_update_edges" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `create_or_update_edges`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/graphs/edges', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_or_update_nodes(self, body, container_id, **kwargs):  # noqa: E501
        """Create Or Update Nodes  # noqa: E501

        This endpoint will either create new nodes or update nodes if a `modified_at` property with a valid DateTime is passed.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_or_update_nodes(body, container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateOrUpdateNodesRequest body: (required)
        :param str container_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_or_update_nodes_with_http_info(body, container_id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_or_update_nodes_with_http_info(body, container_id, **kwargs)  # noqa: E501
            return data

    def create_or_update_nodes_with_http_info(self, body, container_id, **kwargs):  # noqa: E501
        """Create Or Update Nodes  # noqa: E501

        This endpoint will either create new nodes or update nodes if a `modified_at` property with a valid DateTime is passed.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_or_update_nodes_with_http_info(body, container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CreateOrUpdateNodesRequest body: (required)
        :param str container_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'container_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_or_update_nodes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_or_update_nodes`")  # noqa: E501
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `create_or_update_nodes`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/graphs/nodes', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_node_file(self, container_id, node_id, file_id, **kwargs):  # noqa: E501
        """Detach Node File  # noqa: E501

        Detach file from node  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_node_file(container_id, node_id, file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str node_id: (required)
        :param str file_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_node_file_with_http_info(container_id, node_id, file_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_node_file_with_http_info(container_id, node_id, file_id, **kwargs)  # noqa: E501
            return data

    def delete_node_file_with_http_info(self, container_id, node_id, file_id, **kwargs):  # noqa: E501
        """Detach Node File  # noqa: E501

        Detach file from node  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_node_file_with_http_info(container_id, node_id, file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str node_id: (required)
        :param str file_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'node_id', 'file_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_node_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `delete_node_file`")  # noqa: E501
        # verify the required parameter 'node_id' is set
        if ('node_id' not in params or
                params['node_id'] is None):
            raise ValueError("Missing the required parameter `node_id` when calling `delete_node_file`")  # noqa: E501
        # verify the required parameter 'file_id' is set
        if ('file_id' not in params or
                params['file_id'] is None):
            raise ValueError("Missing the required parameter `file_id` when calling `delete_node_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'node_id' in params:
            path_params['node_id'] = params['node_id']  # noqa: E501
        if 'file_id' in params:
            path_params['file_id'] = params['file_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/graphs/nodes/{node_id}/files/{file_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def detach_node_file(self, container_id, file_id, edge_id, **kwargs):  # noqa: E501
        """Detach Node File  # noqa: E501

        Detach file from an edge.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.detach_node_file(container_id, file_id, edge_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str file_id: (required)
        :param str edge_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.detach_node_file_with_http_info(container_id, file_id, edge_id, **kwargs)  # noqa: E501
        else:
            (data) = self.detach_node_file_with_http_info(container_id, file_id, edge_id, **kwargs)  # noqa: E501
            return data

    def detach_node_file_with_http_info(self, container_id, file_id, edge_id, **kwargs):  # noqa: E501
        """Detach Node File  # noqa: E501

        Detach file from an edge.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.detach_node_file_with_http_info(container_id, file_id, edge_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str file_id: (required)
        :param str edge_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'file_id', 'edge_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method detach_node_file" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `detach_node_file`")  # noqa: E501
        # verify the required parameter 'file_id' is set
        if ('file_id' not in params or
                params['file_id'] is None):
            raise ValueError("Missing the required parameter `file_id` when calling `detach_node_file`")  # noqa: E501
        # verify the required parameter 'edge_id' is set
        if ('edge_id' not in params or
                params['edge_id'] is None):
            raise ValueError("Missing the required parameter `edge_id` when calling `detach_node_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'file_id' in params:
            path_params['file_id'] = params['file_id']  # noqa: E501
        if 'edge_id' in params:
            path_params['edge_id'] = params['edge_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/graphs/edges/{edge_id}/files/{file_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_edge_files(self, container_id, edge_id, **kwargs):  # noqa: E501
        """List Edge Files  # noqa: E501

        Lists all attached files for edge.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_edge_files(container_id, edge_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str edge_id: (required)
        :return: ListEdgeFiles
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_edge_files_with_http_info(container_id, edge_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_edge_files_with_http_info(container_id, edge_id, **kwargs)  # noqa: E501
            return data

    def list_edge_files_with_http_info(self, container_id, edge_id, **kwargs):  # noqa: E501
        """List Edge Files  # noqa: E501

        Lists all attached files for edge.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_edge_files_with_http_info(container_id, edge_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str edge_id: (required)
        :return: ListEdgeFiles
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'edge_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_edge_files" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `list_edge_files`")  # noqa: E501
        # verify the required parameter 'edge_id' is set
        if ('edge_id' not in params or
                params['edge_id'] is None):
            raise ValueError("Missing the required parameter `edge_id` when calling `list_edge_files`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'edge_id' in params:
            path_params['edge_id'] = params['edge_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/graphs/edges/{edge_id}/files', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListEdgeFiles',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_edges(self, container_id, **kwargs):  # noqa: E501
        """List Edges  # noqa: E501

        List Edges from storage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_edges(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param int limit:
        :param int offset:
        :param str origin_id:
        :param str destination_id:
        :param str relationship_pair_id:
        :param str relationship_pair_name:
        :return: ListEdgesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_edges_with_http_info(container_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_edges_with_http_info(container_id, **kwargs)  # noqa: E501
            return data

    def list_edges_with_http_info(self, container_id, **kwargs):  # noqa: E501
        """List Edges  # noqa: E501

        List Edges from storage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_edges_with_http_info(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param int limit:
        :param int offset:
        :param str origin_id:
        :param str destination_id:
        :param str relationship_pair_id:
        :param str relationship_pair_name:
        :return: ListEdgesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'limit', 'offset', 'origin_id', 'destination_id', 'relationship_pair_id', 'relationship_pair_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_edges" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `list_edges`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'origin_id' in params:
            query_params.append(('originID', params['origin_id']))  # noqa: E501
        if 'destination_id' in params:
            query_params.append(('destinationID', params['destination_id']))  # noqa: E501
        if 'relationship_pair_id' in params:
            query_params.append(('relationshipPairID', params['relationship_pair_id']))  # noqa: E501
        if 'relationship_pair_name' in params:
            query_params.append(('relationshipPairName', params['relationship_pair_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/graphs/edges', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListEdgesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_node_files(self, container_id, node_id, **kwargs):  # noqa: E501
        """List Node Files  # noqa: E501

        Lists all attached files for node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_node_files(container_id, node_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str node_id: (required)
        :return: ListNodeFiles
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_node_files_with_http_info(container_id, node_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_node_files_with_http_info(container_id, node_id, **kwargs)  # noqa: E501
            return data

    def list_node_files_with_http_info(self, container_id, node_id, **kwargs):  # noqa: E501
        """List Node Files  # noqa: E501

        Lists all attached files for node.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_node_files_with_http_info(container_id, node_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str node_id: (required)
        :return: ListNodeFiles
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'node_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_node_files" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `list_node_files`")  # noqa: E501
        # verify the required parameter 'node_id' is set
        if ('node_id' not in params or
                params['node_id'] is None):
            raise ValueError("Missing the required parameter `node_id` when calling `list_node_files`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'node_id' in params:
            path_params['node_id'] = params['node_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/graphs/nodes/{node_id}/files', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListNodeFiles',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_nodes(self, container_id, **kwargs):  # noqa: E501
        """List Nodes  # noqa: E501

        List nodes  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_nodes(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param int limit:
        :param int offset:
        :param str transformation_id: Return only nodes for the selected type transformation
        :param str metatype_id: Return only nodes for the selected metatype
        :return: ListNodesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_nodes_with_http_info(container_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_nodes_with_http_info(container_id, **kwargs)  # noqa: E501
            return data

    def list_nodes_with_http_info(self, container_id, **kwargs):  # noqa: E501
        """List Nodes  # noqa: E501

        List nodes  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_nodes_with_http_info(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param int limit:
        :param int offset:
        :param str transformation_id: Return only nodes for the selected type transformation
        :param str metatype_id: Return only nodes for the selected metatype
        :return: ListNodesResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'limit', 'offset', 'transformation_id', 'metatype_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_nodes" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `list_nodes`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'transformation_id' in params:
            query_params.append(('transformationID', params['transformation_id']))  # noqa: E501
        if 'metatype_id' in params:
            query_params.append(('metatypeID', params['metatype_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/graphs/nodes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListNodesResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_nodes_by_metatype_id(self, container_id, metatype_id, **kwargs):  # noqa: E501
        """List Nodes By Metatype ID  # noqa: E501

        List Nodes, filter by MetatypeID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_nodes_by_metatype_id(container_id, metatype_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str metatype_id: (required)
        :param int limit:
        :param int offset:
        :return: ListNodesByMetatypeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_nodes_by_metatype_id_with_http_info(container_id, metatype_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_nodes_by_metatype_id_with_http_info(container_id, metatype_id, **kwargs)  # noqa: E501
            return data

    def list_nodes_by_metatype_id_with_http_info(self, container_id, metatype_id, **kwargs):  # noqa: E501
        """List Nodes By Metatype ID  # noqa: E501

        List Nodes, filter by MetatypeID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_nodes_by_metatype_id_with_http_info(container_id, metatype_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str metatype_id: (required)
        :param int limit:
        :param int offset:
        :return: ListNodesByMetatypeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'metatype_id', 'limit', 'offset']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_nodes_by_metatype_id" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `list_nodes_by_metatype_id`")  # noqa: E501
        # verify the required parameter 'metatype_id' is set
        if ('metatype_id' not in params or
                params['metatype_id'] is None):
            raise ValueError("Missing the required parameter `metatype_id` when calling `list_nodes_by_metatype_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'metatype_id' in params:
            path_params['metatype_id'] = params['metatype_id']  # noqa: E501

        query_params = []
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/graphs/nodes/metatype/{metatype_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListNodesByMetatypeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_edge(self, container_id, edge_id, **kwargs):  # noqa: E501
        """Retrieve Edge  # noqa: E501

        Retrieve a single edge  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_edge(container_id, edge_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str edge_id: (required)
        :return: GetEdgeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_edge_with_http_info(container_id, edge_id, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_edge_with_http_info(container_id, edge_id, **kwargs)  # noqa: E501
            return data

    def retrieve_edge_with_http_info(self, container_id, edge_id, **kwargs):  # noqa: E501
        """Retrieve Edge  # noqa: E501

        Retrieve a single edge  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_edge_with_http_info(container_id, edge_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str edge_id: (required)
        :return: GetEdgeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'edge_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_edge" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `retrieve_edge`")  # noqa: E501
        # verify the required parameter 'edge_id' is set
        if ('edge_id' not in params or
                params['edge_id'] is None):
            raise ValueError("Missing the required parameter `edge_id` when calling `retrieve_edge`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'edge_id' in params:
            path_params['edge_id'] = params['edge_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/graphs/edges/{edge_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetEdgeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_node(self, container_id, node_id, **kwargs):  # noqa: E501
        """Retrieve Node  # noqa: E501

        Retrieve a single node from storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_node(container_id, node_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str node_id: (required)
        :return: GetNodeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_node_with_http_info(container_id, node_id, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_node_with_http_info(container_id, node_id, **kwargs)  # noqa: E501
            return data

    def retrieve_node_with_http_info(self, container_id, node_id, **kwargs):  # noqa: E501
        """Retrieve Node  # noqa: E501

        Retrieve a single node from storage.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_node_with_http_info(container_id, node_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str node_id: (required)
        :return: GetNodeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'node_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_node" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `retrieve_node`")  # noqa: E501
        # verify the required parameter 'node_id' is set
        if ('node_id' not in params or
                params['node_id'] is None):
            raise ValueError("Missing the required parameter `node_id` when calling `retrieve_node`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'node_id' in params:
            path_params['node_id'] = params['node_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['BearerAuth']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/graphs/nodes/{node_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetNodeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.users_api import UsersApi  # noqa: E501
from swagger_client.rest import ApiException


class TestUsersApi(unittest.TestCase):
    """UsersApi unit test stubs"""

    def setUp(self):
        self.api = UsersApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_accept_container_invite(self):
        """Test case for accept_container_invite

        AcceptContainerInvite  # noqa: E501
        """
        pass

    def test_assign_user_role(self):
        """Test case for assign_user_role

        AssignUserRole  # noqa: E501
        """
        pass

    def test_delete_user(self):
        """Test case for delete_user

        DeleteUser  # noqa: E501
        """
        pass

    def test_invite_user_to_container(self):
        """Test case for invite_user_to_container

        InviteUserToContainer  # noqa: E501
        """
        pass

    def test_list_invited_users_for_container(self):
        """Test case for list_invited_users_for_container

        ListInvitedUsersForContainer  # noqa: E501
        """
        pass

    def test_list_outstanding_invites(self):
        """Test case for list_outstanding_invites

        ListOutstandingInvites  # noqa: E501
        """
        pass

    def test_list_user_permissions(self):
        """Test case for list_user_permissions

        ListUserPermissions  # noqa: E501
        """
        pass

    def test_list_users(self):
        """Test case for list_users

        ListUsers  # noqa: E501
        """
        pass

    def test_list_users_for_container(self):
        """Test case for list_users_for_container

        ListUsersForContainer  # noqa: E501
        """
        pass

    def test_list_users_roles(self):
        """Test case for list_users_roles

        ListUsersRoles  # noqa: E501
        """
        pass

    def test_retrieve_user(self):
        """Test case for retrieve_user

        RetrieveUser  # noqa: E501
        """
        pass

    def test_update_user(self):
        """Test case for update_user

        UpdateUser  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RSAStatusResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'attempt_response_code': 'str',
        'attempt_reason_code': 'str',
        'subject_name': 'str',
        'authn_policy_id': 'str',
        'session_attributes': 'list[str]',
        'successful_methods': 'list[str]',
        'attempt_expires': 'str'
    }

    attribute_map = {
        'attempt_response_code': 'attemptResponseCode',
        'attempt_reason_code': 'attemptReasonCode',
        'subject_name': 'subjectName',
        'authn_policy_id': 'authnPolicyId',
        'session_attributes': 'sessionAttributes',
        'successful_methods': 'successfulMethods',
        'attempt_expires': 'attemptExpires'
    }

    def __init__(self, attempt_response_code=None, attempt_reason_code=None, subject_name=None, authn_policy_id=None, session_attributes=None, successful_methods=None, attempt_expires=None):  # noqa: E501
        """RSAStatusResponse - a model defined in Swagger"""  # noqa: E501
        self._attempt_response_code = None
        self._attempt_reason_code = None
        self._subject_name = None
        self._authn_policy_id = None
        self._session_attributes = None
        self._successful_methods = None
        self._attempt_expires = None
        self.discriminator = None
        if attempt_response_code is not None:
            self.attempt_response_code = attempt_response_code
        if attempt_reason_code is not None:
            self.attempt_reason_code = attempt_reason_code
        if subject_name is not None:
            self.subject_name = subject_name
        if authn_policy_id is not None:
            self.authn_policy_id = authn_policy_id
        if session_attributes is not None:
            self.session_attributes = session_attributes
        if successful_methods is not None:
            self.successful_methods = successful_methods
        if attempt_expires is not None:
            self.attempt_expires = attempt_expires

    @property
    def attempt_response_code(self):
        """Gets the attempt_response_code of this RSAStatusResponse.  # noqa: E501


        :return: The attempt_response_code of this RSAStatusResponse.  # noqa: E501
        :rtype: str
        """
        return self._attempt_response_code

    @attempt_response_code.setter
    def attempt_response_code(self, attempt_response_code):
        """Sets the attempt_response_code of this RSAStatusResponse.


        :param attempt_response_code: The attempt_response_code of this RSAStatusResponse.  # noqa: E501
        :type: str
        """

        self._attempt_response_code = attempt_response_code

    @property
    def attempt_reason_code(self):
        """Gets the attempt_reason_code of this RSAStatusResponse.  # noqa: E501


        :return: The attempt_reason_code of this RSAStatusResponse.  # noqa: E501
        :rtype: str
        """
        return self._attempt_reason_code

    @attempt_reason_code.setter
    def attempt_reason_code(self, attempt_reason_code):
        """Sets the attempt_reason_code of this RSAStatusResponse.


        :param attempt_reason_code: The attempt_reason_code of this RSAStatusResponse.  # noqa: E501
        :type: str
        """

        self._attempt_reason_code = attempt_reason_code

    @property
    def subject_name(self):
        """Gets the subject_name of this RSAStatusResponse.  # noqa: E501


        :return: The subject_name of this RSAStatusResponse.  # noqa: E501
        :rtype: str
        """
        return self._subject_name

    @subject_name.setter
    def subject_name(self, subject_name):
        """Sets the subject_name of this RSAStatusResponse.


        :param subject_name: The subject_name of this RSAStatusResponse.  # noqa: E501
        :type: str
        """

        self._subject_name = subject_name

    @property
    def authn_policy_id(self):
        """Gets the authn_policy_id of this RSAStatusResponse.  # noqa: E501


        :return: The authn_policy_id of this RSAStatusResponse.  # noqa: E501
        :rtype: str
        """
        return self._authn_policy_id

    @authn_policy_id.setter
    def authn_policy_id(self, authn_policy_id):
        """Sets the authn_policy_id of this RSAStatusResponse.


        :param authn_policy_id: The authn_policy_id of this RSAStatusResponse.  # noqa: E501
        :type: str
        """

        self._authn_policy_id = authn_policy_id

    @property
    def session_attributes(self):
        """Gets the session_attributes of this RSAStatusResponse.  # noqa: E501


        :return: The session_attributes of this RSAStatusResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._session_attributes

    @session_attributes.setter
    def session_attributes(self, session_attributes):
        """Sets the session_attributes of this RSAStatusResponse.


        :param session_attributes: The session_attributes of this RSAStatusResponse.  # noqa: E501
        :type: list[str]
        """

        self._session_attributes = session_attributes

    @property
    def successful_methods(self):
        """Gets the successful_methods of this RSAStatusResponse.  # noqa: E501


        :return: The successful_methods of this RSAStatusResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._successful_methods

    @successful_methods.setter
    def successful_methods(self, successful_methods):
        """Sets the successful_methods of this RSAStatusResponse.


        :param successful_methods: The successful_methods of this RSAStatusResponse.  # noqa: E501
        :type: list[str]
        """

        self._successful_methods = successful_methods

    @property
    def attempt_expires(self):
        """Gets the attempt_expires of this RSAStatusResponse.  # noqa: E501


        :return: The attempt_expires of this RSAStatusResponse.  # noqa: E501
        :rtype: str
        """
        return self._attempt_expires

    @attempt_expires.setter
    def attempt_expires(self, attempt_expires):
        """Sets the attempt_expires of this RSAStatusResponse.


        :param attempt_expires: The attempt_expires of this RSAStatusResponse.  # noqa: E501
        :type: str
        """

        self._attempt_expires = attempt_expires

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RSAStatusResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RSAStatusResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa
"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

# import models into model package
from deep_lynx.models.add_data_to_import_response import AddDataToImportResponse
from deep_lynx.models.assign_role_request import AssignRoleRequest
from deep_lynx.models.batch_container_update_request import BatchContainerUpdateRequest
from deep_lynx.models.batch_container_update_request_inner import BatchContainerUpdateRequestInner
from deep_lynx.models.batch_update_container_response import BatchUpdateContainerResponse
from deep_lynx.models.container import Container
from deep_lynx.models.container_config import ContainerConfig
from deep_lynx.models.container_import_request import ContainerImportRequest
from deep_lynx.models.container_import_response import ContainerImportResponse
from deep_lynx.models.container_import_update_response import ContainerImportUpdateResponse
from deep_lynx.models.container_invite import ContainerInvite
from deep_lynx.models.create_container_request import CreateContainerRequest
from deep_lynx.models.create_container_response import CreateContainerResponse
from deep_lynx.models.create_data_export_request import CreateDataExportRequest
from deep_lynx.models.create_data_source_config import CreateDataSourceConfig
from deep_lynx.models.create_data_source_request import CreateDataSourceRequest
from deep_lynx.models.create_data_sources_response import CreateDataSourcesResponse
from deep_lynx.models.create_event_response import CreateEventResponse
from deep_lynx.models.create_import_response import CreateImportResponse
from deep_lynx.models.create_manual_import import CreateManualImport
from deep_lynx.models.create_manual_import_response import CreateManualImportResponse
from deep_lynx.models.create_metatype_key_request import CreateMetatypeKeyRequest
from deep_lynx.models.create_metatype_keys_response import CreateMetatypeKeysResponse
from deep_lynx.models.create_metatype_relationship_key_request import CreateMetatypeRelationshipKeyRequest
from deep_lynx.models.create_metatype_relationship_keys_response import CreateMetatypeRelationshipKeysResponse
from deep_lynx.models.create_metatype_relationship_pair_request import CreateMetatypeRelationshipPairRequest
from deep_lynx.models.create_metatype_relationship_pairs_response import CreateMetatypeRelationshipPairsResponse
from deep_lynx.models.create_metatype_relationship_request import CreateMetatypeRelationshipRequest
from deep_lynx.models.create_metatype_relationships_response import CreateMetatypeRelationshipsResponse
from deep_lynx.models.create_metatype_request import CreateMetatypeRequest
from deep_lynx.models.create_metatypes_response import CreateMetatypesResponse
from deep_lynx.models.create_or_update_edges_request import CreateOrUpdateEdgesRequest
from deep_lynx.models.create_or_update_nodes_request import CreateOrUpdateNodesRequest
from deep_lynx.models.create_registered_event_request import CreateRegisteredEventRequest
from deep_lynx.models.create_task_response import CreateTaskResponse
from deep_lynx.models.create_transformation_response import CreateTransformationResponse
from deep_lynx.models.create_type_mapping_transformations_request import CreateTypeMappingTransformationsRequest
from deep_lynx.models.data_export_config import DataExportConfig
from deep_lynx.models.data_source import DataSource
from deep_lynx.models.data_source_config import DataSourceConfig
from deep_lynx.models.data_source_id_files_body import DataSourceIdFilesBody
from deep_lynx.models.data_source_id_imports_body import DataSourceIdImportsBody
from deep_lynx.models.data_source_import import DataSourceImport
from deep_lynx.models.data_staging import DataStaging
from deep_lynx.models.edge import Edge
from deep_lynx.models.error_model import ErrorModel
from deep_lynx.models.error_response import ErrorResponse
from deep_lynx.models.event import Event
from deep_lynx.models.exporter import Exporter
from deep_lynx.models.exporter_config import ExporterConfig
from deep_lynx.models.file_info import FileInfo
from deep_lynx.models.file_model import FileModel
from deep_lynx.models.generic200_response import Generic200Response
from deep_lynx.models.get_container_response import GetContainerResponse
from deep_lynx.models.get_data_export_response import GetDataExportResponse
from deep_lynx.models.get_data_source_response import GetDataSourceResponse
from deep_lynx.models.get_data_type_mapping_response import GetDataTypeMappingResponse
from deep_lynx.models.get_edge_response import GetEdgeResponse
from deep_lynx.models.get_event_response import GetEventResponse
from deep_lynx.models.get_file_info_response import GetFileInfoResponse
from deep_lynx.models.get_import_data_response import GetImportDataResponse
from deep_lynx.models.get_metatype_key_response import GetMetatypeKeyResponse
from deep_lynx.models.get_metatype_relationship_key_response import GetMetatypeRelationshipKeyResponse
from deep_lynx.models.get_metatype_relationship_pair_response import GetMetatypeRelationshipPairResponse
from deep_lynx.models.get_metatype_relationship_response import GetMetatypeRelationshipResponse
from deep_lynx.models.get_metatype_response import GetMetatypeResponse
from deep_lynx.models.get_node_response import GetNodeResponse
from deep_lynx.models.get_task_response import GetTaskResponse
from deep_lynx.models.get_user_response import GetUserResponse
from deep_lynx.models.import_data_type_mapping_response import ImportDataTypeMappingResponse
from deep_lynx.models.import_data_type_mapping_response_inner import ImportDataTypeMappingResponseInner
from deep_lynx.models.import_id_data_body import ImportIdDataBody
from deep_lynx.models.import_model import ImportModel
from deep_lynx.models.inline_response200 import InlineResponse200
from deep_lynx.models.key_validation import KeyValidation
from deep_lynx.models.list_container_invites_response import ListContainerInvitesResponse
from deep_lynx.models.list_container_response import ListContainerResponse
from deep_lynx.models.list_data_exports_response import ListDataExportsResponse
from deep_lynx.models.list_data_source_imports_response import ListDataSourceImportsResponse
from deep_lynx.models.list_data_sources_response import ListDataSourcesResponse
from deep_lynx.models.list_data_type_mapping_response import ListDataTypeMappingResponse
from deep_lynx.models.list_edge_files import ListEdgeFiles
from deep_lynx.models.list_edges_response import ListEdgesResponse
from deep_lynx.models.list_events_response import ListEventsResponse
from deep_lynx.models.list_import_data_response import ListImportDataResponse
from deep_lynx.models.list_metatype_keys_response import ListMetatypeKeysResponse
from deep_lynx.models.list_metatype_relationship_keys_response import ListMetatypeRelationshipKeysResponse
from deep_lynx.models.list_metatype_relationship_pairs_response import ListMetatypeRelationshipPairsResponse
from deep_lynx.models.list_metatype_relationships_response import ListMetatypeRelationshipsResponse
from deep_lynx.models.list_metatypes_response import ListMetatypesResponse
from deep_lynx.models.list_node_files import ListNodeFiles
from deep_lynx.models.list_nodes_by_metatype_response import ListNodesByMetatypeResponse
from deep_lynx.models.list_nodes_response import ListNodesResponse
from deep_lynx.models.list_tasks_response import ListTasksResponse
from deep_lynx.models.list_transformation_response import ListTransformationResponse
from deep_lynx.models.list_user_invites_response import ListUserInvitesResponse
from deep_lynx.models.list_user_permissions_response import ListUserPermissionsResponse
from deep_lynx.models.list_user_roles import ListUserRoles
from deep_lynx.models.list_users_for_container_response import ListUsersForContainerResponse
from deep_lynx.models.list_users_response import ListUsersResponse
from deep_lynx.models.mappings_import_body import MappingsImportBody
from deep_lynx.models.metatype import Metatype
from deep_lynx.models.metatype_key import MetatypeKey
from deep_lynx.models.metatype_relationship import MetatypeRelationship
from deep_lynx.models.node import Node
from deep_lynx.models.node_metatype_body import NodeMetatypeBody
from deep_lynx.models.not_found404 import NotFound404
from deep_lynx.models.one_of_upload_file_response import OneOfUploadFileResponse
from deep_lynx.models.rsa_cancel_request import RSACancelRequest
from deep_lynx.models.rsa_init_request import RSAInitRequest
from deep_lynx.models.rsa_response import RSAResponse
from deep_lynx.models.rsa_response_value import RSAResponseValue
from deep_lynx.models.rsa_response_value_challenge_methods import RSAResponseValueChallengeMethods
from deep_lynx.models.rsa_response_value_challenge_methods_challenges import RSAResponseValueChallengeMethodsChallenges
from deep_lynx.models.rsa_response_value_challenge_methods_prompt import RSAResponseValueChallengeMethodsPrompt
from deep_lynx.models.rsa_response_value_challenge_methods_required_methods import RSAResponseValueChallengeMethodsRequiredMethods
from deep_lynx.models.rsa_response_value_challenge_methods_versions import RSAResponseValueChallengeMethodsVersions
from deep_lynx.models.rsa_response_value_context import RSAResponseValueContext
from deep_lynx.models.rsa_response_value_credential_validation_results import RSAResponseValueCredentialValidationResults
from deep_lynx.models.rsa_status_request import RSAStatusRequest
from deep_lynx.models.rsa_status_response import RSAStatusResponse
from deep_lynx.models.rsa_verify_request import RSAVerifyRequest
from deep_lynx.models.relationship_key import RelationshipKey
from deep_lynx.models.relationship_pair import RelationshipPair
from deep_lynx.models.relationship_pair_destination_metatype import RelationshipPairDestinationMetatype
from deep_lynx.models.task import Task
from deep_lynx.models.task_config import TaskConfig
from deep_lynx.models.token_exchange_request import TokenExchangeRequest
from deep_lynx.models.transformation import Transformation
from deep_lynx.models.transformation_condition import TransformationCondition
from deep_lynx.models.transformation_key import TransformationKey
from deep_lynx.models.type_mapping import TypeMapping
from deep_lynx.models.type_mapping_export_payload import TypeMappingExportPayload
from deep_lynx.models.update_container_request import UpdateContainerRequest
from deep_lynx.models.update_container_request_config import UpdateContainerRequestConfig
from deep_lynx.models.update_container_response import UpdateContainerResponse
from deep_lynx.models.update_data_source_response import UpdateDataSourceResponse
from deep_lynx.models.update_data_type_mapping_response import UpdateDataTypeMappingResponse
from deep_lynx.models.update_import_data_response import UpdateImportDataResponse
from deep_lynx.models.update_metatype_key_response import UpdateMetatypeKeyResponse
from deep_lynx.models.update_metatype_relationship_key_response import UpdateMetatypeRelationshipKeyResponse
from deep_lynx.models.update_metatype_relationship_pair_response import UpdateMetatypeRelationshipPairResponse
from deep_lynx.models.update_metatype_relationship_request import UpdateMetatypeRelationshipRequest
from deep_lynx.models.update_metatype_relationship_response import UpdateMetatypeRelationshipResponse
from deep_lynx.models.update_metatype_request import UpdateMetatypeRequest
from deep_lynx.models.update_metatype_response import UpdateMetatypeResponse
from deep_lynx.models.update_registered_event_request import UpdateRegisteredEventRequest
from deep_lynx.models.update_task_response import UpdateTaskResponse
from deep_lynx.models.update_transformation_response import UpdateTransformationResponse
from deep_lynx.models.upload_file_response import UploadFileResponse
from deep_lynx.models.user import User
from deep_lynx.models.user_key import UserKey
from deep_lynx.models.validate_metatype_properties_response import ValidateMetatypePropertiesResponse



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from deep_lynx.api.authentication_api import AuthenticationApi
from deep_lynx.api.containers_api import ContainersApi
from deep_lynx.api.data_export_api import DataExportApi
from deep_lynx.api.data_query_api import DataQueryApi
from deep_lynx.api.data_sources_api import DataSourcesApi
from deep_lynx.api.data_type_mappings_api import DataTypeMappingsApi
from deep_lynx.api.events_api import EventsApi
from deep_lynx.api.graph_api import GraphApi
from deep_lynx.api.imports_api import ImportsApi
from deep_lynx.api.metatype_keys_api import MetatypeKeysApi
from deep_lynx.api.metatype_relationship_keys_api import MetatypeRelationshipKeysApi
from deep_lynx.api.metatype_relationship_pairs_api import MetatypeRelationshipPairsApi
from deep_lynx.api.metatype_relationships_api import MetatypeRelationshipsApi
from deep_lynx.api.metatypes_api import MetatypesApi
from deep_lynx.api.misc_api import MiscApi
from deep_lynx.api.tasks_api import TasksApi
from deep_lynx.api.users_api import UsersApi



# coding: utf-8

"""
    Deep Lynx

    The construction of megaprojects has consistently demonstrated challenges for project managers in regard to meeting cost, schedule, and performance requirements. Megaproject construction challenges are common place within megaprojects with many active projects in the United States failing to meet cost and schedule efforts by significant margins. Currently, engineering teams operate in siloed tools and disparate teams where connections across design, procurement, and construction systems are translated manually or over brittle point-to-point integrations. The manual nature of data exchange increases the risk of silent errors in the reactor design, with each silent error cascading across the design. These cascading errors lead to uncontrollable risk during construction, resulting in significant delays and cost overruns. Deep Lynx allows for an integrated platform during design and operations of mega projects.  The Deep Lynx Core API delivers a few main features.  1. Provides a set of methods and endpoints for manipulating data in an object oriented database. This allows us to store complex datatypes as records and then to compile them into actual, modifiable objects at run-time. Users can store taxonomies or ontologies in a readable format.  2. Provides methods for storing and retrieving data in a graph database. This data is structured and validated against the aformentioned object oriented database before storage.  # noqa: E501

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from swagger_client.api_client import ApiClient


class DataExportApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_data_export(self, body, container_id, **kwargs):  # noqa: E501
        """CreateDataExport  # noqa: E501

        Create a new data export with the included configuration. Configuration values may be encrypted depending on the adapter you've choosen. See the readme for the exporters for more information.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_data_export(body, container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param NewDataExportRequest body: (required)
        :param str container_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_data_export_with_http_info(body, container_id, **kwargs)  # noqa: E501
        else:
            (data) = self.create_data_export_with_http_info(body, container_id, **kwargs)  # noqa: E501
            return data

    def create_data_export_with_http_info(self, body, container_id, **kwargs):  # noqa: E501
        """CreateDataExport  # noqa: E501

        Create a new data export with the included configuration. Configuration values may be encrypted depending on the adapter you've choosen. See the readme for the exporters for more information.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_data_export_with_http_info(body, container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param NewDataExportRequest body: (required)
        :param str container_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'container_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_data_export" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_data_export`")  # noqa: E501
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `create_data_export`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/data/export', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_data_export(self, container_id, export_id, **kwargs):  # noqa: E501
        """DeleteDataExport  # noqa: E501

        Deletes a data export record. This does not guarantee the export will stop immediately.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_data_export(container_id, export_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str export_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_data_export_with_http_info(container_id, export_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_data_export_with_http_info(container_id, export_id, **kwargs)  # noqa: E501
            return data

    def delete_data_export_with_http_info(self, container_id, export_id, **kwargs):  # noqa: E501
        """DeleteDataExport  # noqa: E501

        Deletes a data export record. This does not guarantee the export will stop immediately.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_data_export_with_http_info(container_id, export_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str export_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'export_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_data_export" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `delete_data_export`")  # noqa: E501
        # verify the required parameter 'export_id' is set
        if ('export_id' not in params or
                params['export_id'] is None):
            raise ValueError("Missing the required parameter `export_id` when calling `delete_data_export`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'export_id' in params:
            path_params['export_id'] = params['export_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/data/export/{export_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_data_exports(self, container_id, **kwargs):  # noqa: E501
        """ListDataExports  # noqa: E501

        List data exports for the container.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_data_exports(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param bool count: boolean indicating if the return value should be a count only
        :param int limit:
        :param int offset:
        :param str sort_by: column to sort results by
        :param bool sort_desc: boolean indicating if results should be in descending order
        :return: ListDataExportsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_data_exports_with_http_info(container_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_data_exports_with_http_info(container_id, **kwargs)  # noqa: E501
            return data

    def list_data_exports_with_http_info(self, container_id, **kwargs):  # noqa: E501
        """ListDataExports  # noqa: E501

        List data exports for the container.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_data_exports_with_http_info(container_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param bool count: boolean indicating if the return value should be a count only
        :param int limit:
        :param int offset:
        :param str sort_by: column to sort results by
        :param bool sort_desc: boolean indicating if results should be in descending order
        :return: ListDataExportsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'count', 'limit', 'offset', 'sort_by', 'sort_desc']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_data_exports" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `list_data_exports`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501

        query_params = []
        if 'count' in params:
            query_params.append(('count', params['count']))  # noqa: E501
        if 'limit' in params:
            query_params.append(('limit', params['limit']))  # noqa: E501
        if 'offset' in params:
            query_params.append(('offset', params['offset']))  # noqa: E501
        if 'sort_by' in params:
            query_params.append(('sortBy', params['sort_by']))  # noqa: E501
        if 'sort_desc' in params:
            query_params.append(('sortDesc', params['sort_desc']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/data/export', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListDataExportsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_data_export(self, container_id, export_id, **kwargs):  # noqa: E501
        """RetrieveDataExport  # noqa: E501

        Fetch a data export record by ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_data_export(container_id, export_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str export_id: (required)
        :return: GetDataExportResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_data_export_with_http_info(container_id, export_id, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_data_export_with_http_info(container_id, export_id, **kwargs)  # noqa: E501
            return data

    def retrieve_data_export_with_http_info(self, container_id, export_id, **kwargs):  # noqa: E501
        """RetrieveDataExport  # noqa: E501

        Fetch a data export record by ID  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_data_export_with_http_info(container_id, export_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str export_id: (required)
        :return: GetDataExportResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'export_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_data_export" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `retrieve_data_export`")  # noqa: E501
        # verify the required parameter 'export_id' is set
        if ('export_id' not in params or
                params['export_id'] is None):
            raise ValueError("Missing the required parameter `export_id` when calling `retrieve_data_export`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'export_id' in params:
            path_params['export_id'] = params['export_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/data/export/{export_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetDataExportResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def start_data_export(self, container_id, export_id, **kwargs):  # noqa: E501
        """StartDataExport  # noqa: E501

        Start or restart a data export by id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_data_export(container_id, export_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str export_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.start_data_export_with_http_info(container_id, export_id, **kwargs)  # noqa: E501
        else:
            (data) = self.start_data_export_with_http_info(container_id, export_id, **kwargs)  # noqa: E501
            return data

    def start_data_export_with_http_info(self, container_id, export_id, **kwargs):  # noqa: E501
        """StartDataExport  # noqa: E501

        Start or restart a data export by id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_data_export_with_http_info(container_id, export_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str export_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'export_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_data_export" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `start_data_export`")  # noqa: E501
        # verify the required parameter 'export_id' is set
        if ('export_id' not in params or
                params['export_id'] is None):
            raise ValueError("Missing the required parameter `export_id` when calling `start_data_export`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'export_id' in params:
            path_params['export_id'] = params['export_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/data/export/{export_id}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def stop_data_export(self, container_id, export_id, **kwargs):  # noqa: E501
        """StopDataExport  # noqa: E501

        Stops a data export. Please note that this just sends a **stop** signal. The application's export adapter determines how to handle the said signal. In some cases the export stopping might not be immediate.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.stop_data_export(container_id, export_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str export_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.stop_data_export_with_http_info(container_id, export_id, **kwargs)  # noqa: E501
        else:
            (data) = self.stop_data_export_with_http_info(container_id, export_id, **kwargs)  # noqa: E501
            return data

    def stop_data_export_with_http_info(self, container_id, export_id, **kwargs):  # noqa: E501
        """StopDataExport  # noqa: E501

        Stops a data export. Please note that this just sends a **stop** signal. The application's export adapter determines how to handle the said signal. In some cases the export stopping might not be immediate.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.stop_data_export_with_http_info(container_id, export_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str container_id: (required)
        :param str export_id: (required)
        :return: Generic200Response
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['container_id', 'export_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method stop_data_export" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'container_id' is set
        if ('container_id' not in params or
                params['container_id'] is None):
            raise ValueError("Missing the required parameter `container_id` when calling `stop_data_export`")  # noqa: E501
        # verify the required parameter 'export_id' is set
        if ('export_id' not in params or
                params['export_id'] is None):
            raise ValueError("Missing the required parameter `export_id` when calling `stop_data_export`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'container_id' in params:
            path_params['container_id'] = params['container_id']  # noqa: E501
        if 'export_id' in params:
            path_params['export_id'] = params['export_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['httpBearer']  # noqa: E501

        return self.api_client.call_api(
            '/containers/{container_id}/data/export/{export_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Generic200Response',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
